EXPORTS
	??1CEmailTestUtils@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CEmailTestUtils::~CEmailTestUtils(void)
	?CheckLogOutputL@CScriptTestUtils@@QAEHHABVTDesC16@@@Z @ 2 NONAME ; public: int __thiscall CScriptTestUtils::CheckLogOutputL(int,class TDesC16 const &)
	?CopyScriptFileL@CEmailTestUtils@@QAEXABVTDesC16@@00@Z @ 3 NONAME ; public: void __thiscall CEmailTestUtils::CopyScriptFileL(class TDesC16 const &,class TDesC16 const &,class TDesC16 const &)
	?CopyScriptFileL@CEmailTestUtils@@QAEXABVTDesC16@@0@Z @ 4 NONAME ; public: void __thiscall CEmailTestUtils::CopyScriptFileL(class TDesC16 const &,class TDesC16 const &)
	?CreateAllTestDirectories@CEmailTestUtils@@UAEXXZ @ 5 NONAME ; public: virtual void __thiscall CEmailTestUtils::CreateAllTestDirectories(void)
	?CreateImapServerMtmRegL@CEmailTestUtils@@QAEXXZ @ 6 NONAME ; public: void __thiscall CEmailTestUtils::CreateImapServerMtmRegL(void)
	?CreateImapServiceL@CEmailTestUtils@@QAEJXZ @ 7 NONAME ; public: long __thiscall CEmailTestUtils::CreateImapServiceL(void)
	?CreateMessageFilesL@CEmailTestUtils@@QAEXJJ@Z @ 8 NONAME ; public: void __thiscall CEmailTestUtils::CreateMessageFilesL(long,long)
	?CreateMessageFilesL@CEmailTestUtils@@QAEXJJABVTDesC16@@@Z @ 9 NONAME ; public: void __thiscall CEmailTestUtils::CreateMessageFilesL(long,long,class TDesC16 const &)
	?CreateMessageL@CEmailTestUtils@@QAEXABVTDesC16@@JJ@Z @ 10 NONAME ; public: void __thiscall CEmailTestUtils::CreateMessageL(class TDesC16 const &,long,long)
	?CreatePopServerMtmRegL@CEmailTestUtils@@QAEXXZ @ 11 NONAME ; public: void __thiscall CEmailTestUtils::CreatePopServerMtmRegL(void)
	?CreatePopServiceL@CEmailTestUtils@@QAEJXZ @ 12 NONAME ; public: long __thiscall CEmailTestUtils::CreatePopServiceL(void)
	?CreateServerMtmRegsL@CEmailTestUtils@@UAEXXZ @ 13 NONAME ; public: virtual void __thiscall CEmailTestUtils::CreateServerMtmRegsL(void)
	?CreateServicesL@CEmailTestUtils@@UAEXXZ @ 14 NONAME ; public: virtual void __thiscall CEmailTestUtils::CreateServicesL(void)
	?CreateSmtpServerMtmRegL@CEmailTestUtils@@QAEXXZ @ 15 NONAME ; public: void __thiscall CEmailTestUtils::CreateSmtpServerMtmRegL(void)
	?CreateSmtpServiceL@CEmailTestUtils@@QAEJXZ @ 16 NONAME ; public: long __thiscall CEmailTestUtils::CreateSmtpServiceL(void)
	?DeleteImapServiceL@CEmailTestUtils@@QAEXXZ @ 17 NONAME ; public: void __thiscall CEmailTestUtils::DeleteImapServiceL(void)
	?DeletePopServiceL@CEmailTestUtils@@QAEXXZ @ 18 NONAME ; public: void __thiscall CEmailTestUtils::DeletePopServiceL(void)
	?DeleteServicesL@CEmailTestUtils@@UAEXXZ @ 19 NONAME ; public: virtual void __thiscall CEmailTestUtils::DeleteServicesL(void)
	?DeleteSmtpServiceL@CEmailTestUtils@@QAEXXZ @ 20 NONAME ; public: void __thiscall CEmailTestUtils::DeleteSmtpServiceL(void)
	?ErrorActualL@CScriptTestUtils@@QAEPAVHBufC16@@XZ @ 21 NONAME ; public: class HBufC16 * __thiscall CScriptTestUtils::ErrorActualL(void)
	?ErrorExpectedL@CScriptTestUtils@@QAEPAVHBufC16@@XZ @ 22 NONAME ; public: class HBufC16 * __thiscall CScriptTestUtils::ErrorExpectedL(void)
	?ErrorLineNumber@CScriptTestUtils@@QAEHXZ @ 23 NONAME ; public: int __thiscall CScriptTestUtils::ErrorLineNumber(void)
	?FindExistingServicesL@CEmailTestUtils@@UAEXXZ @ 24 NONAME ; public: virtual void __thiscall CEmailTestUtils::FindExistingServicesL(void)
	?FindImapServiceL@CEmailTestUtils@@QAEJXZ @ 25 NONAME ; public: long __thiscall CEmailTestUtils::FindImapServiceL(void)
	?FindPopServiceL@CEmailTestUtils@@QAEJXZ @ 26 NONAME ; public: long __thiscall CEmailTestUtils::FindPopServiceL(void)
	?FindSmtpServiceL@CEmailTestUtils@@QAEJXZ @ 27 NONAME ; public: long __thiscall CEmailTestUtils::FindSmtpServiceL(void)
	?InstallImapMtmGroupL@CEmailTestUtils@@QAEXXZ @ 28 NONAME ; public: void __thiscall CEmailTestUtils::InstallImapMtmGroupL(void)
	?InstallMtmGroupsL@CEmailTestUtils@@UAEXXZ @ 29 NONAME ; public: virtual void __thiscall CEmailTestUtils::InstallMtmGroupsL(void)
	?InstallPopMtmGroupL@CEmailTestUtils@@QAEXXZ @ 30 NONAME ; public: void __thiscall CEmailTestUtils::InstallPopMtmGroupL(void)
	?InstallSmtpMtmGroupL@CEmailTestUtils@@QAEXXZ @ 31 NONAME ; public: void __thiscall CEmailTestUtils::InstallSmtpMtmGroupL(void)
	?InstantiateClientMtmsL@CEmailTestUtils@@UAEXXZ @ 32 NONAME ; public: virtual void __thiscall CEmailTestUtils::InstantiateClientMtmsL(void)
	?InstantiateImapClientMtmL@CEmailTestUtils@@QAEXXZ @ 33 NONAME ; public: void __thiscall CEmailTestUtils::InstantiateImapClientMtmL(void)
	?InstantiateImapServerMtmL@CEmailTestUtils@@QAEXXZ @ 34 NONAME ; public: void __thiscall CEmailTestUtils::InstantiateImapServerMtmL(void)
	?InstantiatePopClientMtmL@CEmailTestUtils@@QAEXXZ @ 35 NONAME ; public: void __thiscall CEmailTestUtils::InstantiatePopClientMtmL(void)
	?InstantiatePopServerMtmL@CEmailTestUtils@@QAEXXZ @ 36 NONAME ; public: void __thiscall CEmailTestUtils::InstantiatePopServerMtmL(void)
	?InstantiateServerMtmsL@CEmailTestUtils@@UAEXXZ @ 37 NONAME ; public: virtual void __thiscall CEmailTestUtils::InstantiateServerMtmsL(void)
	?InstantiateSmtpClientMtmL@CEmailTestUtils@@QAEXXZ @ 38 NONAME ; public: void __thiscall CEmailTestUtils::InstantiateSmtpClientMtmL(void)
	?InstantiateSmtpServerMtmL@CEmailTestUtils@@QAEXXZ @ 39 NONAME ; public: void __thiscall CEmailTestUtils::InstantiateSmtpServerMtmL(void)
	?ListChildrenL@CEmailTestUtils@@UAEXAAVRFile@@AAVCDir@@AAH2HH@Z @ 40 NONAME ; public: virtual void __thiscall CEmailTestUtils::ListChildrenL(class RFile &,class CDir &,int &,int &,int,int)
	?LogToInputFileL@CScriptTestUtils@@QAEXABVTDesC16@@0H@Z @ 41 NONAME ; public: void __thiscall CScriptTestUtils::LogToInputFileL(class TDesC16 const &,class TDesC16 const &,int)
	?LogToOutputFileL@CScriptTestUtils@@QAEXABVTDesC16@@0H@Z @ 42 NONAME ; public: void __thiscall CScriptTestUtils::LogToOutputFileL(class TDesC16 const &,class TDesC16 const &,int)
	?NewL@CEmailTestUtils@@SAPAV1@AAVRTest@@I@Z @ 43 NONAME ; public: static class CEmailTestUtils * __cdecl CEmailTestUtils::NewL(class RTest &,unsigned int)
	?NewLC@CEmailTestUtils@@SAPAV1@AAVRTest@@I@Z @ 44 NONAME ; public: static class CEmailTestUtils * __cdecl CEmailTestUtils::NewLC(class RTest &,unsigned int)
	?NewLC@CScriptTestUtils@@SAPAV1@AAVCEmailTestUtils@@@Z @ 45 NONAME ; public: static class CScriptTestUtils * __cdecl CScriptTestUtils::NewLC(class CEmailTestUtils &)
	?Reset@CEmailTestUtils@@UAEXXZ @ 46 NONAME ; public: virtual void __thiscall CEmailTestUtils::Reset(void)
	?StartConnectionL@CEmailTestUtils@@QAEXK@Z @ 47 NONAME ; public: void __thiscall CEmailTestUtils::StartConnectionL(unsigned long)
	?DeleteScriptFilesFromLogsDirL@CEmailTestUtils@@QAEXXZ @ 48 NONAME ; public: void __thiscall CEmailTestUtils::DeleteScriptFilesFromLogsDirL(void)

